/* Copyright (c) 1997, MpegTV LLC */
#ifndef _sii_api_h
#define _sii_api_h
#ifndef lint
static const char rcsid_sii_api_h[] = "$Header: /net/hopkins/var/home/tristan/mpeg/dec/RCS/sii_api.h,v 1.11 1998/05/29 22:19:16 tristan Exp $";
#endif

/*
 * Disclaimer of Warranty
 *
 * These software programs are available to the user without any license fee or
 * royalty on an "as is" basis.  Copyright-holder disclaims
 * any and all warranties, whether express, implied, or statuary, including any
 * implied warranties or merchantability or of fitness for a particular
 * purpose.  In no event shall the copyright-holder be liable for any
 * incidental, punitive, or consequential damages of any kind whatsoever
 * arising from the use of these programs.
 *
 * This disclaimer of warranty extends to the user of these programs and user's
 * customers, employees, agents, transferees, successors, and assigns.
 *
 */

#include "misc.h"

/*--------------------------------------------------------------------------+
| Macros																	|
+--------------------------------------------------------------------------*/

/*
 * SII_read may return -1 with errno set to SII_READ_ERROR_TOO_SMALL to
 * indicate that the count passed is too small. This feature is very useful
 * for example when reading UDP sockets.  When reading a UDP socket, the
 * read count passed to the 'read' routine should always be at least
 * the maximum UDP packet size expected, otherwise some data can be lost.
 * SII_READ_ERROR_TOO_SMALL can therefore be returned if SII_read is
 * called with a 'count' value smaller than the maximum UDP packet size expected.
 * Note that the packet payload size should be larger than this maximum
 * UDP packet size expected, otherwise SII_read would always be called with
 * a count too small!
 */
#define SII_READ_ERROR_TOO_SMALL	(-1)

/*--------------------------------------------------------------------------+
| Data types																|
+--------------------------------------------------------------------------*/

/* to specify configuration of input buffer pool */
typedef struct {
	u_int	packet_count;		/* packet count */
	u_int	packet_gross_size;	/* packet total size */
	u_int	packet_payload_size;	/* packet payload size */
	u_int	packet_offset;		/* packet header size (i.e. offset to payload) */
	
	/* following are experimental */
	
#if 0 /* Tristan Savatier - Mon Mar 16 18:29:23 PST 1998 */
//	u_int	free_count_trigger;	/* dont start reading unless # free packets > this (default 0) */
#endif /* 0 - Tristan Savatier - Mon Mar 16 18:29:23 PST 1998 */
#if 0 /* Tristan Savatier - Tue Feb 24 15:43:54 PST 1998 */
//	u_int	list_count_trigger;	/* experimental (default 0) */
#endif /* 0 - Tristan Savatier - Tue Feb 24 15:43:54 PST 1998 */
} SIB_IPL_SIZES;


/*--------------------------------------------------------------------------+
| Externals																	|
+--------------------------------------------------------------------------*/
#ifdef __cplusplus
extern "C" {
#endif

extern int sii_feedback(const void *data, u_int size);

extern int _init(void);
extern int _fini(void);
extern void *SII_open(const void *data, u_int size);
extern int SII_close(void *stream);
extern int SII_read(void *stream, char *buf, size_t count);
extern off_t SII_lseek(void *stream, off_t offset, int whence);
extern int SII_cntl(void *stream, const void *data, u_int size);
extern int SII_fd(void *stream);
extern off_t SII_size(void *io_data);
extern void SII_buffer(void *stream, SIB_IPL_SIZES *sizes);

#ifdef __cplusplus
}
#endif

#endif /* _sii_api_h */
